==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/NPCTrackOwnerAttackerGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.entity.ai.goal.util.EntityTargetUtil;
import cc.thonly.reverie_dreams.entity.npc.NPCEntityImpl;
import java.util.EnumSet;
import net.minecraft.class_1309;
import net.minecraft.class_1321;
import net.minecraft.class_1352;
import net.minecraft.class_1405;
import net.minecraft.class_4051;
import net.minecraft.class_6025;

public class NPCTrackOwnerAttackerGoal extends class_1405 {
    private final class_1321 tameable;
    private class_1309 attacker;
    private int lastAttackedTime;

    public NPCTrackOwnerAttackerGoal(class_1321 tameable) {
        super(tameable, false);
        this.tameable = tameable;
        this.method_6265(EnumSet.of(class_1352.class_4134.field_18408));
    }

    @Override
    public boolean method_6264() {
        if (!this.tameable.method_6181() || this.tameable.method_24345()) {
            return false;
        }
        class_1309 livingEntity = this.tameable.method_35057();
        if (livingEntity == null) {
            return false;
        }
        if (livingEntity instanceof class_6025 targetEntity) {
            if (this.tameable.method_35057() == targetEntity.method_35057()) {
                return false;
            }
        }
        this.attacker = livingEntity.method_6065();
        int i = livingEntity.method_6117();
        boolean isMaid = tameable instanceof NPCEntityImpl;
        return i != this.lastAttackedTime && (isMaid && EntityTargetUtil.canAttack(attacker, (NPCEntityImpl) tameable)) && this.method_6328(this.attacker, class_4051.field_18092) && this.tameable.method_6178(this.attacker, livingEntity);
    }

    @Override
    public void method_6269() {
        this.field_6660.method_5980(this.attacker);
        class_1309 livingEntity = this.tameable.method_35057();
        if (livingEntity != null) {
            this.lastAttackedTime = livingEntity.method_6117();
        }
        super.method_6269();
    }

}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/NPCTrackOwnerAttackerGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.entity.ai.goal.util.EntityTargetUtil;
import cc.thonly.reverie_dreams.entity.npc.BaseNPCLikeEntity;
import java.util.EnumSet;
import net.minecraft.class_1309;
import net.minecraft.class_1321;
import net.minecraft.class_1352;
import net.minecraft.class_1405;
import net.minecraft.class_4051;
import net.minecraft.class_6025;

public class NPCTrackOwnerAttackerGoal extends class_1405 {
    private final class_1321 tameable;
    private class_1309 attacker;
    private int lastAttackedTime;

    public NPCTrackOwnerAttackerGoal(class_1321 tameable) {
        super(tameable, false);
        this.tameable = tameable;
        this.method_6265(EnumSet.of(class_1352.class_4134.field_18408));
    }

    @Override
    public boolean method_6264() {
        if (!this.tameable.method_6181() || this.tameable.method_24345()) {
            return false;
        }
        class_1309 livingEntity = this.tameable.method_35057();
        if (livingEntity == null) {
            return false;
        }
        if (livingEntity instanceof class_6025 targetEntity) {
            if (this.tameable.method_35057() == targetEntity.method_35057()) {
                return false;
            }
        }
        this.attacker = livingEntity.method_6065();
        int i = livingEntity.method_6117();
        boolean isMaid = tameable instanceof BaseNPCLikeEntity;
        return i != this.lastAttackedTime && (isMaid && EntityTargetUtil.canAttack(attacker, (BaseNPCLikeEntity) tameable)) && this.method_6328(this.attacker, class_4051.field_18092) && this.tameable.method_6178(this.attacker, livingEntity);
    }

    @Override
    public void method_6269() {
        this.field_6660.method_5980(this.attacker);
        class_1309 livingEntity = this.tameable.method_35057();
        if (livingEntity != null) {
            this.lastAttackedTime = livingEntity.method_6117();
        }
        super.method_6269();
    }

}
